==> python-dateparser-0.7.6-1-any.pkg.tar.xz: usr/lib/python3.8/site-packages/dateparser/data/date_translation_data/hsb.py <==
# -*- coding: utf-8 -*-
info = {
    "name": "hsb",
    "date_order": "DMY",
    "january": [
        "januar",
        "jan",
        "januara"
    ],
    "february": [
        "februar",
        "feb",
        "februara"
    ],
    "march": [
        "měrc",
        "měr",
        "měrca"
    ],
    "april": [
        "apryl",
        "apr",
        "apryla"
    ],
    "may": [
        "meja",
        "mej",
        "meje"
    ],
    "june": [
        "junij",
        "jun",
        "junija"
    ],
    "july": [
        "julij",
        "jul",
        "julija"
    ],
    "august": [
        "awgust",
        "awg",
        "awgusta"
    ],
    "september": [
        "september",
        "sep",
        "septembra"
    ],
    "october": [
        "oktober",
        "okt",
        "oktobra"
    ],
    "november": [
        "nowember",
        "now",
        "nowembra"
    ],
    "december": [
        "december",
        "dec",
        "decembra"
    ],
    "monday": [
        "póndźela",
        "pón"
    ],
    "tuesday": [
        "wutora",
        "wut"
    ],
    "wednesday": [
        "srjeda",
        "srj"
    ],
    "thursday": [
        "štwórtk",
        "štw"
    ],
    "friday": [
        "pjatk",
        "pja"
    ],
    "saturday": [
        "sobota",
        "sob"
    ],
    "sunday": [
        "njedźela",
        "nje"
    ],
    "am": [
        "dopołdnja"
    ],
    "pm": [
        "popołdnju"
    ],
    "year": [
        "lěto",
        "l"
    ],
    "month": [
        "měsac",
        "měs"
    ],
    "week": [
        "tydźeń",
        "tydź"
    ],
    "day": [
        "dźeń",
        "d"
    ],
    "hour": [
        "hodźina",
        "hodź",
        "h"
    ],
    "minute": [
        "minuta",
        "min",
        "m"
    ],
    "second": [
        "sekunda",
        "sek",
        "s"
    ],
    "relative-type": {
        "1 year ago": [
            "loni"
        ],
        "0 year ago": [
            "lětsa"
        ],
        "in 1 year": [
            "klětu"
        ],
        "1 month ago": [
            "zašły měsac"
        ],
        "0 month ago": [
            "tutón měsac"
        ],
        "in 1 month": [
            "přichodny měsac"
        ],
        "1 week ago": [
            "zašły tydźeń"
        ],
        "0 week ago": [
            "tutón tydźeń"
        ],
        "in 1 week": [
            "přichodny tydźeń"
        ],
        "1 day ago": [
            "wčera"
        ],
        "0 day ago": [
            "dźensa"
        ],
        "in 1 day": [
            "jutře"
        ],
        "0 hour ago": [
            "this hour"
        ],
        "0 minute ago": [
            "this minute"
        ],
        "0 second ago": [
            "now"
        ]
    },
    "relative-type-regex": {
        "in \\1 year": [
            "za (\\d+) lěto",
            "za (\\d+) lět",
            "za (\\d+) l"
        ],
        "\\1 year ago": [
            "před (\\d+) lětom",
            "před (\\d+) lětami",
            "před (\\d+) l"
        ],
        "in \\1 month": [
            "za (\\d+) měsac",
            "za (\\d+) měsacow",
            "za (\\d+) měs"
        ],
        "\\1 month ago": [
            "před (\\d+) měsacom",
            "před (\\d+) měsacami",
            "před (\\d+) měs"
        ],
        "in \\1 week": [
            "za (\\d+) tydźeń",
            "za (\\d+) tydźenjow",
            "za (\\d+) tydź"
        ],
        "\\1 week ago": [
            "před (\\d+) tydźenjom",
            "před (\\d+) tydźenjemi",
            "před (\\d+) tydź"
        ],
        "in \\1 day": [
            "za (\\d+) dźeń",
            "za (\\d+) dnjow",
            "za (\\d+) dnj",
            "za (\\d+) d"
        ],
        "\\1 day ago": [
            "před (\\d+) dnjom",
            "před (\\d+) dnjemi",
            "před (\\d+) dnj",
            "před (\\d+) d"
        ],
        "in \\1 hour": [
            "za (\\d+) hodźinu",
            "za (\\d+) hodźin",
            "za (\\d+) hodź",
            "za (\\d+) h"
        ],
        "\\1 hour ago": [
            "před (\\d+) hodźinu",
            "před (\\d+) hodźinami",
            "před (\\d+) hodź",
            "před (\\d+) h"
        ],
        "in \\1 minute": [
            "za (\\d+) minutu",
            "za (\\d+) minutow",
            "za (\\d+) min",
            "za (\\d+) m"
        ],
        "\\1 minute ago": [
            "před (\\d+) minutu",
            "před (\\d+) minutami",
            "před (\\d+) min",
            "před (\\d+) m"
        ],
        "in \\1 second": [
            "za (\\d+) sekundu",
            "za (\\d+) sekundow",
            "za (\\d+) sek",
            "za (\\d+) s"
        ],
        "\\1 second ago": [
            "před (\\d+) sekundu",
            "před (\\d+) sekundami",
            "před (\\d+) sek",
            "před (\\d+) s"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        ".",
        ",",
        ";",
        "-",
        "/",
        "'",
        "|",
        "@",
        "[",
        "]",
        "，"
    ]
}

==> python-dateparser-1.1.1-1-any.pkg.tar.xz: usr/lib/python3.10/site-packages/dateparser/data/date_translation_data/hsb.py <==
info = {
    "name": "hsb",
    "date_order": "DMY",
    "january": [
        "jan",
        "januar",
        "januara"
    ],
    "february": [
        "feb",
        "februar",
        "februara"
    ],
    "march": [
        "měr",
        "měrc",
        "měrca"
    ],
    "april": [
        "apr",
        "apryl",
        "apryla"
    ],
    "may": [
        "mej",
        "meja",
        "meje"
    ],
    "june": [
        "jun",
        "junij",
        "junija"
    ],
    "july": [
        "jul",
        "julij",
        "julija"
    ],
    "august": [
        "awg",
        "awgust",
        "awgusta"
    ],
    "september": [
        "sep",
        "september",
        "septembra"
    ],
    "october": [
        "okt",
        "oktober",
        "oktobra"
    ],
    "november": [
        "now",
        "nowember",
        "nowembra"
    ],
    "december": [
        "dec",
        "december",
        "decembra"
    ],
    "monday": [
        "pón",
        "póndźela"
    ],
    "tuesday": [
        "wut",
        "wutora"
    ],
    "wednesday": [
        "srj",
        "srjeda"
    ],
    "thursday": [
        "štw",
        "štwórtk"
    ],
    "friday": [
        "pja",
        "pjatk"
    ],
    "saturday": [
        "sob",
        "sobota"
    ],
    "sunday": [
        "nje",
        "njedźela"
    ],
    "am": [
        "dopołdnja"
    ],
    "pm": [
        "popołdnju"
    ],
    "year": [
        "l",
        "lěto"
    ],
    "month": [
        "měs",
        "měsac"
    ],
    "week": [
        "tydź",
        "tydźeń"
    ],
    "day": [
        "d",
        "dźeń"
    ],
    "hour": [
        "h",
        "hodź",
        "hodźina"
    ],
    "minute": [
        "m",
        "min",
        "minuta"
    ],
    "second": [
        "s",
        "sek",
        "sekunda"
    ],
    "relative-type": {
        "0 day ago": [
            "dźensa"
        ],
        "0 hour ago": [
            "this hour"
        ],
        "0 minute ago": [
            "this minute"
        ],
        "0 month ago": [
            "tutón měsac"
        ],
        "0 second ago": [
            "now"
        ],
        "0 week ago": [
            "tutón tydźeń"
        ],
        "0 year ago": [
            "lětsa"
        ],
        "1 day ago": [
            "wčera"
        ],
        "1 month ago": [
            "zašły měsac"
        ],
        "1 week ago": [
            "zašły tydźeń"
        ],
        "1 year ago": [
            "loni"
        ],
        "in 1 day": [
            "jutře"
        ],
        "in 1 month": [
            "přichodny měsac"
        ],
        "in 1 week": [
            "přichodny tydźeń"
        ],
        "in 1 year": [
            "klětu"
        ]
    },
    "relative-type-regex": {
        "\\1 day ago": [
            "před (\\d+) d",
            "před (\\d+) dnj",
            "před (\\d+) dnjemi",
            "před (\\d+) dnjom"
        ],
        "\\1 hour ago": [
            "před (\\d+) h",
            "před (\\d+) hodź",
            "před (\\d+) hodźinami",
            "před (\\d+) hodźinu"
        ],
        "\\1 minute ago": [
            "před (\\d+) m",
            "před (\\d+) min",
            "před (\\d+) minutami",
            "před (\\d+) minutu"
        ],
        "\\1 month ago": [
            "před (\\d+) měs",
            "před (\\d+) měsacami",
            "před (\\d+) měsacom"
        ],
        "\\1 second ago": [
            "před (\\d+) s",
            "před (\\d+) sek",
            "před (\\d+) sekundami",
            "před (\\d+) sekundu"
        ],
        "\\1 week ago": [
            "před (\\d+) tydź",
            "před (\\d+) tydźenjemi",
            "před (\\d+) tydźenjom"
        ],
        "\\1 year ago": [
            "před (\\d+) l",
            "před (\\d+) lětami",
            "před (\\d+) lětom"
        ],
        "in \\1 day": [
            "za (\\d+) d",
            "za (\\d+) dnj",
            "za (\\d+) dnjow",
            "za (\\d+) dźeń"
        ],
        "in \\1 hour": [
            "za (\\d+) h",
            "za (\\d+) hodź",
            "za (\\d+) hodźin",
            "za (\\d+) hodźinu"
        ],
        "in \\1 minute": [
            "za (\\d+) m",
            "za (\\d+) min",
            "za (\\d+) minutow",
            "za (\\d+) minutu"
        ],
        "in \\1 month": [
            "za (\\d+) měs",
            "za (\\d+) měsac",
            "za (\\d+) měsacow"
        ],
        "in \\1 second": [
            "za (\\d+) s",
            "za (\\d+) sek",
            "za (\\d+) sekundow",
            "za (\\d+) sekundu"
        ],
        "in \\1 week": [
            "za (\\d+) tydź",
            "za (\\d+) tydźenjow",
            "za (\\d+) tydźeń"
        ],
        "in \\1 year": [
            "za (\\d+) l",
            "za (\\d+) lět",
            "za (\\d+) lěto"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        "'",
        ",",
        "-",
        ".",
        "/",
        ";",
        "@",
        "[",
        "]",
        "|",
        "，"
    ]
}
